classifier

package
v0.0.0-...-ea07d1b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: EUPL-1.2 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrDuplicateCommitType    = errors.New("duplicate commit type")
	ErrNonUnique              = errors.New("non-unique item")
	ErrNonCanonicalCommitType = errors.New("non-canonical commit type")
)

Functions

This section is empty.

Types

type Classification

type Classification int
const (
	None Classification = iota
	Patch
	Minor
	Major
)

type Classifier

type Classifier struct {
	// contains filtered or unexported fields
}

func New

func New(r io.Reader) (*Classifier, error)

New will parse the optional io.Reader r. When r is nil then the default commit type classification is used. For the default classification, "chore", "docs", "refactor", "style" and "test" are None, "feat" is Minor, "fix" and all types others are Patch. When providing a custom classification mapping, make sure to include at least "feat", "fix" and "chore" ith the same mapping.

func (*Classifier) Classify

Jump to