Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
This section is empty.
Types ¶
type Classification ¶
type Classification int
const ( None Classification = iota Patch Minor Major )
type Classifier ¶
type Classifier struct {
// contains filtered or unexported fields
}
func New ¶
func New(r io.Reader) (*Classifier, error)
New will parse the optional io.Reader r. When r is nil then the default commit type classification is used. For the default classification, "chore", "docs", "refactor", "style" and "test" are None, "feat" is Minor, "fix" and all types others are Patch. When providing a custom classification mapping, make sure to include at least "feat", "fix" and "chore" ith the same mapping.
func (*Classifier) Classify ¶
func (c *Classifier) Classify(msg *commitparser.CommitMessage) Classification
Click to show internal directories.
Click to hide internal directories.